"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@heroku-cli/command");
const completions_1 = require("@heroku-cli/command/lib/completions");
const cli_ux_1 = require("cli-ux");
const authorizations_1 = require("../../lib/authorizations");
class AuthorizationsCreate extends command_1.Command {
    async run() {
        const { flags } = this.parse(AuthorizationsCreate);
        cli_ux_1.cli.action.start('Creating OAuth Authorization');
        const { body: auth } = await this.heroku.post('/oauth/authorizations', {
            body: {
                description: flags.description,
                scope: flags.scope ? flags.scope.split(',') : undefined,
                expires_in: flags['expires-in'],
            },
        });
        cli_ux_1.cli.action.stop();
        if (flags.short) {
            cli_ux_1.cli.log(auth.access_token && auth.access_token.token);
        }
        else if (flags.json) {
            cli_ux_1.cli.styledJSON(auth);
        }
        else {
            authorizations_1.display(auth);
        }
    }
}
exports.default = AuthorizationsCreate;
AuthorizationsCreate.description = 'create a new OAuth authorization';
AuthorizationsCreate.examples = [
    '$ heroku authorizations:create --description "For use with Anvil"',
];
AuthorizationsCreate.flags = {
    description: command_1.flags.string({ char: 'd', description: 'set a custom authorization' }),
    short: command_1.flags.boolean({ char: 'S', description: 'only output token' }),
    json: command_1.flags.boolean({ char: 'j', description: 'output in json format' }),
    scope: command_1.flags.string({ char: 's', description: 'set custom OAuth scopes', completion: completions_1.ScopeCompletion }),
    'expires-in': command_1.flags.string({ char: 'e', description: 'set expiration in seconds (default no expiration)' }),
};
