"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const color_1 = require("@heroku-cli/color");
const command_1 = require("@heroku-cli/command");
const cli_ux_1 = require("cli-ux");
const sortBy = require('lodash.sortby');
class AuthorizationsIndex extends command_1.Command {
    async run() {
        const { flags } = this.parse(AuthorizationsIndex);
        let { body: authorizations } = await this.heroku.get('/oauth/authorizations');
        authorizations = sortBy(authorizations, 'description');
        if (flags.json) {
            cli_ux_1.cli.styledJSON(authorizations);
        }
        else if (authorizations.length === 0) {
            cli_ux_1.cli.log('No OAuth authorizations.');
        }
        else {
            cli_ux_1.cli.table(authorizations, {
                description: { get: (v) => color_1.default.green(v.description) },
                id: {},
                scope: { get: (v) => v.scope.join(',') },
            }, { 'no-header': true, printLine: this.log });
        }
    }
}
exports.default = AuthorizationsIndex;
AuthorizationsIndex.description = 'list OAuth authorizations';
AuthorizationsIndex.examples = [
    '$ heroku authorizations',
];
AuthorizationsIndex.flags = {
    json: command_1.flags.boolean({ char: 'j', description: 'output in json format' }),
};
