"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@heroku-cli/command");
const cli_ux_1 = require("cli-ux");
const authorizations_1 = require("../../lib/authorizations");
class AuthorizationsUpdate extends command_1.Command {
    async run() {
        const { args, flags } = this.parse(AuthorizationsUpdate);
        cli_ux_1.cli.action.start('Updating OAuth Authorization');
        let client;
        if (flags['client-id']) {
            client = {
                id: flags['client-id'],
                secret: flags['client-secret'],
            };
        }
        const { body: authentication } = await this.heroku.patch(`/oauth/authorizations/${args.id}`, {
            body: {
                description: flags.description,
                client,
            },
        });
        cli_ux_1.cli.action.stop();
        authorizations_1.display(authentication);
    }
}
exports.default = AuthorizationsUpdate;
AuthorizationsUpdate.description = 'updates an OAuth authorization';
AuthorizationsUpdate.flags = {
    description: command_1.flags.string({ char: 'd', description: 'set a custom authorization description' }),
    'client-id': command_1.flags.string({ description: 'identifier of OAuth client to set', dependsOn: ['client-secret'] }),
    'client-secret': command_1.flags.string({ description: 'secret of OAuth client to set', dependsOn: ['client-id'] }),
};
AuthorizationsUpdate.args = [{ name: 'id', required: true }];
