"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@heroku-cli/command");
const cli_ux_1 = require("cli-ux");
const clients_1 = require("../../lib/clients");
class ClientsCreate extends command_1.Command {
    async run() {
        const { args, flags } = this.parse(ClientsCreate);
        const { redirect_uri, name } = args;
        clients_1.validateURL(redirect_uri);
        cli_ux_1.cli.action.start(`Creating ${args.name}`);
        const { body: client } = await this.heroku.post('/oauth/clients', {
            body: { name, redirect_uri },
        });
        cli_ux_1.cli.action.stop();
        if (flags.json) {
            cli_ux_1.cli.styledJSON(client);
        }
        else {
            cli_ux_1.cli.log(`HEROKU_OAUTH_ID=${client.id}`);
            cli_ux_1.cli.log(`HEROKU_OAUTH_SECRET=${client.secret}`);
        }
    }
}
exports.default = ClientsCreate;
ClientsCreate.description = 'create a new OAuth client';
ClientsCreate.examples = [
    '$ heroku clients:create "Amazing" https://amazing-client.herokuapp.com/auth/heroku/callback',
];
ClientsCreate.flags = {
    json: command_1.flags.boolean({ char: 'j', description: 'output in json format' }),
    shell: command_1.flags.boolean({ char: 's', description: 'output in shell format' }),
};
ClientsCreate.args = [
    { name: 'name', required: true },
    { name: 'redirect_uri', required: true },
];
